from typing import Any

from ms_graph_client.graph_api_crud_base import GraphAPICRUDBASE
from ms_graph_client.graph_api_config import GraphAPIConfig


class Users(GraphAPICRUDBASE):
    def __init__(self, config: GraphAPIConfig):
        super().__init__(config=config)

    def get_user(self, upn: str) -> Any:
        "carpnick2@qkdw.onmicrosoft.com"
        res = self._get(url_part="/users/" + upn)
        return res



from ms_graph_client.graph_api_config import GraphAPIConfig as GraphAPIConfig
from ms_graph_client.services.applications import Applications
from ms_graph_client.services.groups import Groups
from ms_graph_client.services.users import Users

class GraphAPI:
    groups: Groups
    applications: Applications
    users: Users
    def __init__(self, config: GraphAPIConfig) -> None: ...



from ms_graph_client.exceptions import UnableToFindApplicationError
from .groups import Groups as Groups
from ms_graph_client.graph_api_config import GraphAPIConfig as GraphAPIConfig
from ms_graph_client.graph_api_crud_base import GraphAPICRUDBASE as GraphAPICRUDBASE
from typing import Any

class Applications(GraphAPICRUDBASE):
    _group_crud: Groups
    def __init__(self, config: GraphAPIConfig, group_obj: Groups) -> None: ...
    def get_by_application_name(self, app_name: str) -> Any: ...
    def get_service_principal_by_app_id(self, app_id: str) -> Any: ...
    def exists_by_obj_id(self, id: str) -> bool: ...
    def get_by_object_id(self, id: str) -> Any: ...
    def _stabilize_app_assignment(self, app_sp_id: str, group_id: str, should_be_assigned: bool) -> None: ...
    def assign_group_to_app(
        self, app_name: str, group_id: str, with_stabilization: bool, appRole: str = ...
    ) -> Any: ...
    def unassign_group_to_app(
        self, app_name: str, assigned_to_id: str, group_id: str, with_stabilization: bool
    ) -> None: ...



import requests
from .graph_api_config import GraphAPIConfig as GraphAPIConfig
from typing import Any, Optional

class GraphAPICRUDBASE:
    config: GraphAPIConfig
    session: requests.Session
    def __init__(self, config: GraphAPIConfig, session: Optional[requests.Session] = ...) -> None: ...
    def _default_session(self) -> requests.Session: ...
    def _combine_url(self, url_part: str) -> str: ...
    def _token_call(self) -> Any: ...
    def _response_has_json(self, response: requests.Response) -> bool: ...
    def _call(
        self, url: str, body: Optional[Any], json: Optional[Any], method: str, extra_headers: Optional[Any] = ...
    ) -> Any: ...
    def _get(
        self, url_part: str, json: Optional[Any] = ..., body: Optional[Any] = ..., extra_headers: Optional[Any] = ...
    ) -> Any: ...
    def _post(
        self, url_part: str, json: Optional[Any] = ..., body: Optional[Any] = ..., extra_headers: Optional[Any] = ...
    ) -> Any: ...
    def _put(
        self, url_part: str, json: Optional[Any] = ..., body: Optional[Any] = ..., extra_headers: Optional[Any] = ...
    ) -> Any: ...
    def _patch(
        self, url_part: str, json: Optional[Any] = ..., body: Optional[Any] = ..., extra_headers: Optional[Any] = ...
    ) -> Any: ...
    def _delete(
        self, url_part: str, json: Optional[Any] = ..., body: Optional[Any] = ..., extra_headers: Optional[Any] = ...
    ) -> Any: ...



class GraphAPIConfig:
    client_id: str
    tenant_id: str
    client_secret: str
    api_url: str
    def __init__(self, client_id: str, tenant_id: str, client_secret: str, api_url: str) -> None: ...



import enum
import typing
from ms_graph_client.graph_api_config import GraphAPIConfig as GraphAPIConfig
from ms_graph_client.graph_api_crud_base import GraphAPICRUDBASE as GraphAPICRUDBASE
from typing import Any

class Groups(GraphAPICRUDBASE):
    def __init__(self, config: GraphAPIConfig) -> None: ...

    class GroupType(enum.Enum):
        SECURITY: str
        Microsoft365: str
    def is_group_assigned_to_app(self, app_service_principal_id: str, group_id: str) -> bool: ...
    def get_by_name(self, group_name: str) -> Any: ...
    def exists_by_name(self, group_name: str) -> bool: ...
    def delete(self, group_id: str, group_name: str, with_stabilization: bool) -> None: ...
    def update(self, group_id: str, group_name: str) -> None: ...
    def _stabilize_group_existence(self, group_name: str, should_exist: bool) -> None: ...
    def create(self, group_name: str, group_type: GroupType, owners: list[str], with_stabilization: bool) -> str: ...
    def list_group_members(self, group_id: str) -> list[Any]: ...
    def is_member_of_group(self, group_id: str, object_id: str) -> bool: ...
    def _stabilize_member_in_group_existence(self, group_id: str, object_id: str, should_exist: bool) -> None: ...
    def add_member(self, group_id: str, object_id: str, with_stabilization: bool) -> None: ...
    def _chunk_list(self, my_list: list[Any], size: int) -> typing.Iterator[Any]: ...
    def add_members(self, group_id: str, object_ids: list[str]) -> None: ...
    def remove_member(self, group_id: str, object_id: str, with_stabilization: bool) -> None: ...



from ms_graph_client.graph_api_config import GraphAPIConfig
from .groups import Groups
from .applications import Applications
from .users import Users


class GraphAPI:
    def __init__(self, config: GraphAPIConfig):
        self.groups = Groups(config=config)
        self.applications = Applications(config=config, group_obj=self.groups)
        self.users = Users(config=config)
